#include <windows.h> 
#include "GpioLib.h"

///< Demo menu option enum
typedef enum{
	OPTION_INPUT =1,
	OPTION_OUTPUT,
	OPTION_EXIT,
	OPTION_INVALID
}OPTION_FOR_SELECTION;

//******************************************************************************
/// Run gpio demo as output configuration, toggle sodimm number 50 times with 500ms delay
/// @param[in]          sodimm         Sodimm Pin Number               
/// @retval             TRUE           Success
/// @retval             FALSE          Error
BOOL functionOutputDemo(DWORD sodimm)
{
	DWORD loopCount		= 0;				///< Counting variable
	printf("GPIO as Output\n");
	if(!SetPinAltFn(sodimm, -1, DIR_OUT))   ///< Set SODIMM Pin as GPIO(-1) and set to Output
	{
		return FALSE;
	}
	for (loopCount = 0; loopCount < 50; loopCount++)
	{
		printf("Setting Sodimm %d low\n", sodimm);
		SetPinLevel(sodimm, FALSE);     ///< Set the logic level of SODIMM pin to low
		Sleep(500);						///< Delay by 500 ms  
		printf("Setting Sodimm %d high\n", sodimm);
		SetPinLevel(sodimm, TRUE);      ///< Set the logic level of SODIMM pin to high
		Sleep(500);						///< Delay by 500 ms
	}
	return TRUE;
}
//******************************************************************************
/// Run gpio demo as Input configuration and return sodimm level 0 for low, 1 for high
/// @param[in]          sodimm         Sodimm Pin Number               
/// @retval             TRUE           Success
/// @retval             FALSE          Error
void functionInputDemo(DWORD sodimm)
{
	DWORD loopCount		= 0;			///< Counting variable
	BOOL inputVal = FALSE;				///< Variable to store input status
	printf("GPIO as Input\n");
	SetPinAltFn(sodimm, -1, DIR_IN);    ///< Set SODIMM Pin as GPIO(-1) and set to Input
	while(loopCount < 10)
	{
		inputVal = GetPinLevel(sodimm); ///< Get the logic level of SODIMM pin 
		if(inputVal)					///< Print message every time sodimm pin toggle high
		{
			printf("SODIMM pin 101 level: %d\n", inputVal);
			loopCount++;
			Sleep(100);
		}
	}
}
//******************************************************************************
/// Get Sodimm number from console                
/// @retval             sodimm			Success
/// @retval             OPTION_INVALID  Error
DWORD getSodimmNumber()
{
	DWORD sodimmNumber	= 0;
	printf("Enter Sodimm Number\r\n");
	fflush(stdin);
	scanf("%d", &sodimmNumber);						///< Get Sodimm number from console window
	if(sodimmNumber <=0 || sodimmNumber > 300)		///< Check for invalid sodimm number/MXM number 
	{
		printf("Invalid Sodimm number\r\n");
		return OPTION_INVALID;
	}
	return sodimmNumber;
}
int wmain()
{ 
	DWORD selection		= OPTION_INVALID;
	InitGPIOLib();									///< Init GPIO library
	printf("Demo application to show GPIO as Output and Input\r\n");
	while (selection != OPTION_EXIT)
	{
		printf("\n\n********************** Option **********************");
		printf("\n1. Input \n2. Output \n3. Exit\t ");
		fflush(stdin);
		scanf_s("%u", &selection);
		switch(selection)
		{
		case OPTION_INPUT:							///< option to run demo as Input configuration
			functionInputDemo(getSodimmNumber());	
			break;
		case OPTION_OUTPUT:							///< option to run demo as Output configuration
			functionOutputDemo(getSodimmNumber());
			break;
		case OPTION_EXIT:
			DeInitGPIOLib();						///< Release resources used by GPIO lib and de-initialize GPIO library function 
			break;
		default:
			printf("\nInvalid selection. Try again.");
		}
	}
	return(TRUE);
}